Module lib_conf

Copyright © 2017-2018 Jörgen Brandt

Version: 0.1.5

Authors: Jörgen Brandt (joergen.brandt@onlinehome.de).

Function Index

create_conf/5Creates a map by combining a DefaultMap, a map extracted from a ConfigFile, and a ManualMap.

Function Details

create_conf/5

create_conf(DefaultMap, GlobalFile, UserFile, SupplFile, FlagMap) -> #{atom() => term()}

Creates a map by combining a DefaultMap, a map extracted from a ConfigFile, and a ManualMap.

The resulting map contains only keys that were also in DefaultMap. The values for any of these keys are overwritten first with the according values from the ConfFile and then with the according values from the ManualMap.


Generated by EDoc